Use PyGTK in a virtualenv on Linux, Windows or OSX, thanks to Vext.

Vext allows selective use of system python packages in a virtualenv.

Report bugs to the [vext project](//github.com/stuaxo/vext/issues)

# This is *Experimental* I haven't used Qt much, feedback, patches welcome :)
